@@ -2,8 +2,10 @@
 :class:`~allennlp.common.tqdm.Tqdm` wraps tqdm so we can add configurable
 global defaults for certain tqdm parameters.
 """
+from typing import Any
 
 from tqdm import tqdm as _tqdm
+
 # This is neccesary to stop tqdm from hanging
 # when exceptions are raised inside iterators.
 # It should have been fixed in 4.2.1, but it still
@@ -35,10 +37,7 @@ class Tqdm:
             Tqdm.default_mininterval = 0.1
 
     @staticmethod
-    def tqdm(*args, **kwargs):
-        new_kwargs = {
-                'mininterval': Tqdm.default_mininterval,
-                **kwargs
-        }
+    def tqdm(*args: Any, **kwargs: Any) -> Any:
+        new_kwargs = {"mininterval": Tqdm.default_mininterval, **kwargs}
 
         return _tqdm(*args, **new_kwargs)
