@@ -1,3 +1,3 @@
-from .data_iterator import DataIterator
+from .base import DataIterator
 from .bucket_iterator import BucketIterator
 from .bucket_iterator_optimized import BucketIteratorOptimized
