@@ -1,12 +1,16 @@
+from typing import Sequence
+
 import torch
 from torch import nn
-from .pooling import MeanPool, MaxPool
-from .attention import SelfAttention
+
 from vtorch.nn.packed_sequence import get_last_rnn_state
 
+from .attention import SelfAttention
+from .pooling import MaxPool, MeanPool
 
-class Aggregation(nn.Module):
-    def __init__(self, layers, input_dim):
+
+class Aggregation(nn.Module):  # type: ignore
+    def __init__(self, layers: Sequence[str], input_dim: int) -> None:
         super().__init__()
         self.has_max_pool = "max_pool" in layers
         self.has_mean_pool = "mean_pool" in layers
@@ -21,7 +25,9 @@ class Aggregation(nn.Module):
         self._n_layers = len(layers)
         self._input_dim = input_dim
 
-    def forward(self, x, lengths, batch_first=False):
+    def forward(  # type: ignore
+        self, x: torch.Tensor, lengths: torch.Tensor, batch_first: bool = False
+    ) -> torch.Tensor:
         if self._n_layers == 0:
             if lengths is not None:
                 return get_last_rnn_state(x, lengths)
@@ -42,4 +48,3 @@ class Aggregation(nn.Module):
         if self._n_layers != 0:
             return self._n_layers * self._input_dim
         return self._input_dim
-
