@@ -1,12 +1,12 @@
-import torch.nn as nn
-from vtorch.common.registrable import Registrable
+import torch
 
 
-class RNNLayer(nn.Module, Registrable):
+class RNNLayer(torch.nn.Module):  # type: ignore
     """
     RNN layer is a ``Module`` that is the same as default rnn pytorch layers,
-    but registrable and has ``get_output_dim`` method
+    has ``get_output_dim`` method
     """
+
     def get_output_dim(self) -> int:
         """
         Returns output dim based on input data
