@@ -1,3 +1,3 @@
-from .tensorboard_logger import TfLogger
-from .early_stopping import EarlyStopping
 from .callbacks import Callbacks
+from .clearml_reporter import ClearMLReporter
+from .early_stopping import EarlyStopping
