@@ -7,30 +7,26 @@ rather than instantiating a ``Trainer`` yourself.
 """
 
 import logging
-from typing import Dict, List, Union, Any
+from typing import List, Union
 
-from vtorch.common import Registrable
-from vtorch.common.checks import ConfigurationError, check_for_gpu
-from vtorch.models.model import Model
+import torch.nn
+
+from ..common.checks import ConfigurationError, check_for_gpu
 
 logger = logging.getLogger(__name__)
 
 
-class TrainerBase(Registrable):
+class TrainerBase:
     """
     The base class for an AllenNLP trainer. It can do pretty much
     anything you want. Your subclass should implement ``train``
     and also probably ``from_params``.
     """
-    default_implementation = "default"
 
-    def __init__(self,
-                 serialization_dir: str,
-                 cuda_device: Union[int, List] = -1) -> None:
+    def __init__(self, cuda_device: Union[int, List[int]] = -1) -> None:
+        # TODO: remove multiple GPU training and use single device instead
         check_for_gpu(cuda_device)
 
-        self._serialization_dir = serialization_dir
-
         # Configure GPUs:
         if not isinstance(cuda_device, int) and not isinstance(cuda_device, list):
             raise ConfigurationError("Expected an int or list for cuda_device, got {}".format(cuda_device))
@@ -42,13 +38,7 @@ class TrainerBase(Registrable):
             self._multiple_gpu = False
             self._cuda_devices = [cuda_device]
 
-    def _move_to_gpu(self, model: Model) -> Model:
-        if self._cuda_devices[0] != -1:
-            return model.cuda(self._cuda_devices[0])
-        else:
-            return model
-
-    def train(self) -> Dict[str, Any]:
+    def train(self) -> torch.nn.Module:
         """
         Train a model and return the results.
         """
